Crate iridis_node_derive

Crate iridis_node_derive 

This module contains the macros Node and node(runtime). It’s used to generate the necessary boilerplate code for creating a node.

Attribute Macros

node
Use this macro to mark an impl block on a node. This will alter the new and start methods to return a tokio::task::JoinHandle with the provided runtime. The parameter must be a function that takes an async closure and returns a JoinHandle.

Derive Macros

Node
Apply this macro to a struct to generate the C symbols and the according tokio::runtime::Runtime.