This module contains the macros Node and node(runtime).
It’s used to generate the necessary boilerplate code for creating a node.
Attribute Macros
- node
- Use this macro to mark an
implblock on a node. This will alter thenewandstartmethods to return atokio::task::JoinHandlewith the provided runtime. The parameter must be a function that takes anasyncclosure and returns aJoinHandle.
Derive Macros
- Node
- Apply this macro to a struct to generate the
Csymbols and the accordingtokio::runtime::Runtime.